@@ -1,7 +1,6 @@
 use serde::{Deserialize, Serialize};
-use swc_common::{collections::AHashSet, errors::HANDLER, Span, SyntaxContext};
+use swc_common::{errors::HANDLER, Span, SyntaxContext};
 use swc_ecma_ast::*;
-use swc_ecma_utils::{collect_decls_with_ctxt, ident::IdentLike};
 use swc_ecma_visit::{Visit, VisitWith};
 
 use crate::{
@@ -20,15 +19,13 @@ pub struct SymbolDescriptionConfig {
 }
 
 pub fn symbol_description(
-    program: &Program,
-    top_level_ctxt: SyntaxContext,
+    unresolved_ctxt: SyntaxContext,
     config: &RuleConfig<SymbolDescriptionConfig>,
 ) -> Option<Box<dyn Rule>> {
     match config.get_rule_reaction() {
         LintRuleReaction::Off => None,
         _ => Some(visitor_rule(SymbolDescription::new(
-            collect_decls_with_ctxt(program, top_level_ctxt),
-            top_level_ctxt,
+            unresolved_ctxt,
             config,
         ))),
     }
@@ -37,33 +34,25 @@ pub fn symbol_description(
 #[derive(Debug, Default)]
 struct SymbolDescription {
     expected_reaction: LintRuleReaction,
-    top_level_ctxt: SyntaxContext,
-    top_level_declared_vars: AHashSet<Id>,
+    unresolved_ctxt: SyntaxContext,
+
     enforce_string_description: bool,
 }
 
 impl SymbolDescription {
-    fn new(
-        top_level_declared_vars: AHashSet<Id>,
-        top_level_ctxt: SyntaxContext,
-        config: &RuleConfig<SymbolDescriptionConfig>,
-    ) -> Self {
+    fn new(unresolved_ctxt: SyntaxContext, config: &RuleConfig<SymbolDescriptionConfig>) -> Self {
         let rule_config = config.get_rule_config();
 
         Self {
             expected_reaction: config.get_rule_reaction(),
-            top_level_ctxt,
-            top_level_declared_vars,
+            unresolved_ctxt,
+
             enforce_string_description: rule_config.enforce_string_description.unwrap_or(true),
         }
     }
 
     fn is_symbol_call(&self, ident: &Ident) -> bool {
-        if self.top_level_declared_vars.contains(&ident.to_id()) {
-            return false;
-        }
-
-        if ident.span.ctxt != self.top_level_ctxt {
+        if ident.span.ctxt != self.unresolved_ctxt {
             return false;
         }
 
@@ -73,11 +62,7 @@ impl SymbolDescription {
     fn check(&self, span: Span, first_arg: Option<&ExprOrSpread>) {
         if let Some(ExprOrSpread { expr, .. }) = first_arg {
             if self.enforce_string_description {
-                match extract_arg_val(
-                    &self.top_level_ctxt,
-                    &self.top_level_declared_vars,
-                    unwrap_seqs_and_parens(expr),
-                ) {
+                match extract_arg_val(self.unresolved_ctxt, unwrap_seqs_and_parens(expr)) {
                     ArgValue::Str(_) => {}
                     _ => {
                         self.emit_report(span, SYMBOL_STRING_DESCRIPTION_EXPECTED_MESSAGE);
